@@ -14,8 +14,8 @@ pushd docker
 docker build                  \
   --network host              \
   --build-arg LLVM_VERSION=12 \
-  -t bpftrace-builder-bionic  \
-  -f Dockerfile.bionic        \
+  -t bpftrace-builder-focal   \
+  -f Dockerfile.focal         \
   .
 popd
 
@@ -28,4 +28,4 @@ docker run                                \
   -e BPFTRACE_UPDATE_TESTS=1              \
   -e TEST_ARGS="--gtest_filter=codegen.*" \
   -e VENDOR_GTEST="ON"                    \
-  bpftrace-builder-bionic "$(pwd)/build-codegen-update" Debug "$@"
+  bpftrace-builder-focal "$(pwd)/build-codegen-update" Debug "$@"
